@@ -49,14 +49,37 @@ class KdpConn(object):
         auth_response = auth_util.create_authentication_token(config, email, password, workspace_id, strategy)
         return auth_response
 
+
+    # Auth, only applicable if jwt is created for auth-proxy
+    def create_proxy_authentication_token(self, first_name: str, workspace_id: str, jwt: str = None,
+                                    strategy: str = 'proxy') -> object:
+        """This method will be used to authenticate to KDP. Only request from auth-proxy with be accepted.
+
+            :param str first_name: User's first name
+            :param str workspace_id: User workspace
+            :param str strategy: Defaults to "proxy"
+
+            :returns: Authentication token
+
+            :rtype: AuthenticationDetails
+        """
+        config = self.create_configuration(jwt=jwt)
+
+        auth_util = AuthenticationUtil()
+        auth_response = auth_util.create_proxy_authentication_token(config, first_name, workspace_id, strategy)
+        return auth_response
+
+
+
     # WRITE
-    def batch_write(self, dataframe, dataset_id: str, jwt: str, batch_size: int = 100):
+    def batch_write(self, dataframe, dataset_id: str, jwt: str, batch_size: int = 100, is_async: bool = True):
         """This method will be used to write batches of data to KDP
 
             :param DataFrame dataframe: Data to write to KDP
             :param str dataset_id: ID of the KDP dataset where the data will be written
             :param str jwt: JWT token
             :param int batch_size: Defaults to 100
+            :param bool is_async: Defaults to True
 
             :returns: Set of partitions data was written to
 
@@ -64,7 +87,7 @@ class KdpConn(object):
         """
         write_api = WriteApi()
         config = self.create_configuration(jwt)
-        return write_api.batch_write(config=config, dataset_id=dataset_id, dataframe=dataframe, batch_size=batch_size)
+        return write_api.batch_write(config=config, dataset_id=dataset_id, dataframe=dataframe, batch_size=batch_size, is_async=is_async)
 
     def create_url_ingest_job(self, workspace_id: str, dataset_id: str, url_list, jwt: str) -> str:
         """This method will be used to start a job that ingests files to KDP
